@@ -2,7 +2,7 @@
 import argparse
 from getpass import getpass
 
-from api import LidlPlusApi
+from lidlplus import LidlPlusApi
 
 
 def get_arguments():
